@@ -14,12 +14,13 @@ def args(parser):
                                                       'compose path is provided --images should be compose')
     push.add_argument('--compose_services', nargs='+', help='Services for docker compose')
     push.add_argument('--compose_build_cmd', help='string containing additional compose build arguments')
+    push.add_argument('--releases_file', help="name of a file to store list of performed releases")
     return parser
 
 
 def push(tenant, version, conf_path, images=None, equal_tags=None, local_version=None, all_tenants=False,
          auto_incr_version='minor', on_tag_exist=None, on_repository_not_exist=None,
-         docker_compose_path=None, image_prefix=None, compose_services=None, compose_build_cmd=''):
+         docker_compose_path=None, image_prefix=None, compose_services=None, compose_build_cmd='', releases_file=None):
     if tenant is None and all_tenants is False:
         raise ValueError('Specify tenant or pass all_tenants')
     conf = Config(conf_path)
@@ -67,6 +68,16 @@ def push(tenant, version, conf_path, images=None, equal_tags=None, local_version
                                                      tenant_conf['check_is_new_hash']
         release.validate_push(check_is_next=check_is_newest_version,
                               check_new_hash=check_is_new_hash)
+
+    performed_releases = set()
     for tenant_conf, release in releases:
         release.push()
+        performed_releases.add(f"{release.registry_client.registry_name}/{release.name}:{release.version}")
         print(f'Successfully performed release of {release.name} with version: {release.version} on tenant {release.registry_client.registry_name}')
+
+    if not releases_file:
+        return None
+
+    with open(releases_file, "w") as f:
+        for release in performed_releases:
+            f.write(f"{release}\n")
